import json
import tornado.gen
import tornado.tcpserver
from tornado.iostream import StreamClosedError


class TCPServer(tornado.tcpserver.TCPServer):

    def __init__(self, *args, **kwargs):
        super(TCPServer, self).__init__(*args, **kwargs)
        self.report_clients = None

    @tornado.gen.coroutine
    def handle_stream(self, stream, address):
        print('connection from {}'.format(address))

        while True:
            try:
                data = yield stream.read_bytes(4096, partial=True)
                pkg = json.dumps({
                    'op': 'recvd',
                    'is_binary': False,
                    'data': data
                })
                for client in self.report_clients:
                    client.write_message(pkg)

            except StreamClosedError:
                print("fuck")
                break



from os.path import join, dirname
from tornado.web import Application
from tornado.ioloop import IOLoop
from web.admin import LiveHandler,\
					  StaticFileHandler
from argparse import ArgumentParser



basepath = dirname(__file__)
webpath = join(basepath, 'web')
viewspath = join(webpath, 'views')
indexpath = join(viewspath, 'index.html')

urlmap = [
	(r'/live', LiveHandler, ),
	(r'/()$', StaticFileHandler, {'path': indexpath}),
]

def start_loop():
	app = Application(urlmap, report_clients=[])
	app.listen(4991)
	loop = IOLoop.current()
	loop.start()

if __name__ == '__main__':
	start_loop()


import os
import json
from tornado.web import RequestHandler, StaticFileHandler
from tornado.websocket import WebSocketHandler
from tcp import TCPServer


class LiveHandler(WebSocketHandler):

    def open(self):
        clients = self.settings['report_clients']
        clients.append(self)

    def on_close(self):
        clients = self.settings['report_clients']
        clients.remove(self)

    def on_message(self, message):
        data = json.loads(message)
        op = data['op']

        if op == 'listen':
            port = data['port']

            try:
                server = TCPServer()
                server.report_clients = self.settings['report_clients']
                server.listen(port)
                print('listening: {}'.format(port))
            except Exception as ex:
                print(ex)




from setuptools import setup
import sokery

setup(
  name = 'sokery',
  packages = ['sokery', 'sokery.web'],  
  version = sokery.__version__,
  description = 'Socket testing with web interface',
  install_requires=['tornado'],
  author = 'Gamaliel Espinoza',
  author_email = 'gamaliel.espinoza@gmail.com',
  url = 'https://github.com/gamikun/sokery',
  keywords = ['sokery'], 
  classifiers = [],
)
